@@ -31,13 +31,13 @@ fn main() {
     let router = router![home, foo_bar_baz, bar_baz_qux];
     let _response: http::Response<String> = match router(request) {
         // Matched a route
-        Some(Ok(resp)) => resp,
+        Ok(Ok(resp)) => resp,
         // There was an error
-        Some(Err(_err)) => {
+        Ok(Err(_err)) => {
             // convert err into an http::Response;
             todo!()
         }
         // No routes matched
-        None => todo!(),
+        Err(_request) => todo!(),
     };
 }
